def states_cities():

    SC_DATA = {
        "Andhra Pradesh": ["Tirupati", "Visakhapatnam", "Vijayawada", "Guntur", "Kurnool"],
        "Arunachal Pradesh": ["Itanagar", "Pasighat", "Naharlagun", "Ziro", "Tezu"],
        "Assam": ["Dispur", "Guwahati", "Silchar", "Dibrugarh", "Jorhat"],
        "Bihar": ["Patna", "Gaya", "Muzaffarpur", "Bhagalpur", "Darbhanga"],
        "Chhattisgarh": ["Raipur", "Bilaspur", "Durg", "Bhilai", "Raigarh"],
        "Goa": ["Panaji", "Margao", "Vasco da Gama", "Mapusa", "Ponda"],
        "Gujarat": ["Gandhinagar", "Ahmedabad", "Surat", "Vadodara", "Rajkot"],
        "Haryana": ["Chandigarh", "Faridabad", "Gurgaon", "Panipat", "Rohtak"],
        "Himachal Pradesh": ["Shimla", "Mandi", "Dharamshala", "Solan", "Hamirpur"],
        "Jammu and Kashmir": ["Srinagar", "Jammu", "Anantnag", "Baramulla", "Sopore"],
        "Jharkhand": ["Ranchi", "Dhanbad", "Jamshedpur", "Bokaro Steel City", "Deoghar"],
        "Karnataka": ["Bengaluru", "Mysuru", "Hubballi", "Mangaluru", "Belagavi"],
        "Kerala": ["Thiruvananthapuram", "Kochi", "Kannur", "Kozhikode", "Thrissur"],
        "Madhya Pradesh": ["Bhopal", "Indore", "Jabalpur", "Gwalior", "Ujjain"],
        "Maharashtra": ["Mumbai", "Pune", "Nagpur", "Nashik", "Thane"],
        "Manipur": ["Imphal", "Thoubal", "Bishnupur", "Churachandpur", "Kakching"],
        "Meghalaya": ["Shillong", "Jowai", "Tura", "Nongstoin", "Williamnagar"],
        "Mizoram": ["Aizawl", "Lunglei", "Serchhip", "Champhai", "Kolasib"],
        "Nagaland": ["Kohima", "Dimapur", "Mokokchung", "Wokha", "Zunheboto"],
        "Odisha": ["Bhubaneswar", "Cuttack", "Rourkela", "Brahmapur", "Sambalpur"],
        "Punjab": ["Chandigarh", "Ludhiana", "Amritsar", "Jalandhar", "Patiala"],
        "Rajasthan": ["Jaipur", "Jodhpur", "Kota", "Bikaner", "Ajmer"],
        "Sikkim": ["Gangtok", "Gyalshing", "Jorethang", "Mangan", "Namchi"],
        "Tamil Nadu": ["Chennai", "Coimbatore", "Madurai", "Tiruchirappalli", "Salem"],
        "Telangana": ["Hyderabad", "Warangal", "Karimnagar", "Nizamabad", "Khammam"],
        "Tripura": ["Agartala", "Dharmanagar", "Kailashahar", "Udaipur", "Belonia"],
        "Uttar Pradesh": ["Lucknow", "Kanpur", "Varanasi", "Agra", "Meerut"],
        "Uttarakhand": ["Dehradun", "Haridwar", "Rishikesh", "Nainital", "Mussoorie"],
        "West Bengal": ["Kolkata", "Howrah", "Durgapur", "Asansol", "Siliguri"]
    }

    return SC_DATA

def states():

    S_DATA = ['Andhra Pradesh', 'Arunachal Pradesh', 'Assam', 'Bihar', 'Chhattisgarh', 'Goa', 'Gujarat', 'Haryana', 'Himachal Pradesh', 'Jammu and Kashmir', 'Jharkhand', 'Karnataka', 'Kerala', 'Madhya Pradesh', 'Maharashtra', 'Manipur', 'Meghalaya', 'Mizoram', 'Nagaland', 'Odisha', 'Punjab', 'Rajasthan', 'Sikkim', 'Tamil Nadu', 'Telangana', 'Tripura', 'Uttar Pradesh', 'Uttarakhand', 'West Bengal']

    return S_DATA

def cities():

    C_DATA = ['Tirupati', 'Visakhapatnam', 'Vijayawada', 'Guntur', 'Kurnool', 'Itanagar', 'Pasighat', 'Naharlagun', 'Ziro', 'Tezu', 'Dispur', 'Guwahati', 'Silchar', 'Dibrugarh', 'Jorhat', 'Patna', 'Gaya', 'Muzaffarpur', 'Bhagalpur', 'Darbhanga', 'Raipur', 'Bilaspur', 'Durg', 'Bhilai', 'Raigarh', 'Panaji', 'Margao', 'Vasco da Gama', 'Mapusa', 'Ponda', 'Gandhinagar', 'Ahmedabad', 'Surat', 'Vadodara', 'Rajkot', 'Chandigarh', 'Faridabad', 'Gurgaon', 'Panipat', 'Rohtak', 'Shimla', 'Mandi', 'Dharamshala', 'Solan', 'Hamirpur', 'Srinagar', 'Jammu', 'Anantnag', 'Baramulla', 'Sopore', 'Ranchi', 'Dhanbad', 'Jamshedpur', 'Bokaro Steel City', 'Deoghar', 'Bengaluru', 'Mysuru', 'Hubballi', 'Mangaluru', 'Belagavi', 'Thiruvananthapuram', 'Kochi', 'Kannur', 'Kozhikode', 'Thrissur', 'Bhopal', 'Indore', 'Jabalpur', 'Gwalior', 'Ujjain', 'Mumbai', 'Pune', 'Nagpur', 'Nashik', 'Thane', 'Imphal', 'Thoubal', 'Bishnupur', 'Churachandpur', 'Kakching', 'Shillong', 'Jowai', 'Tura', 'Nongstoin', 'Williamnagar', 'Aizawl', 'Lunglei', 'Serchhip', 'Champhai', 'Kolasib', 'Kohima', 'Dimapur', 'Mokokchung', 'Wokha', 'Zunheboto', 'Bhubaneswar', 'Cuttack', 'Rourkela', 'Brahmapur', 'Sambalpur', 'Chandigarh', 'Ludhiana', 'Amritsar', 'Jalandhar', 'Patiala', 'Jaipur', 'Jodhpur', 'Kota', 'Bikaner', 'Ajmer', 'Gangtok', 'Gyalshing', 'Jorethang', 'Mangan', 'Namchi', 'Chennai', 'Coimbatore', 'Madurai', 'Tiruchirappalli', 'Salem', 'Hyderabad', 'Warangal', 'Karimnagar', 'Nizamabad', 'Khammam', 'Agartala', 'Dharmanagar', 'Kailashahar', 'Udaipur', 'Belonia', 'Lucknow', 'Kanpur', 'Varanasi', 'Agra', 'Meerut', 'Dehradun', 'Haridwar', 'Rishikesh', 'Nainital', 'Mussoorie', 'Kolkata', 'Howrah', 'Durgapur', 'Asansol', 'Siliguri']

    return C_DATA